==> haskell-rio-prettyprint-0.1.6.0-34-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rio-prettyprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rio-prettyprint
version:              0.1.6.0
visibility:           public
id:                   rio-prettyprint-0.1.6.0-8yMhW9OlfuNCDIBt7RdLaV
key:                  rio-prettyprint-0.1.6.0-8yMhW9OlfuNCDIBt7RdLaV
license:              BSD-3-Clause
copyright:            2018-2019 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/rio-prettyprint#readme
synopsis:             Pretty-printing for RIO
description:          Combine RIO'\''s log capabilities with pretty printing
category:             Development
abi:                  3548f3772b7ea12a9c80f3141a5ea2b6
exposed:              True
exposed-modules:
    RIO.PrettyPrint RIO.PrettyPrint.DefaultStyles
    RIO.PrettyPrint.PrettyException RIO.PrettyPrint.Simple
    RIO.PrettyPrint.StylesUpdate RIO.PrettyPrint.Types
    Text.PrettyPrint.Leijen.Extended

hidden-modules:       Paths_rio_prettyprint
import-dirs:          /usr/lib/ghc-9.2.8/site-local/rio-prettyprint-0.1.6.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/rio-prettyprint-0.1.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rio-prettyprint
hs-libraries:         HSrio-prettyprint-0.1.6.0-8yMhW9OlfuNCDIBt7RdLaV
depends:
    Cabal-3.6.3.0 aeson-2.1.2.1-5xA96pEAe1OF80YjsNpBtK
    annotated-wl-pprint-0.7.0-JJ8k3Us8XMDCld6qYY6FFz
    ansi-terminal-0.11.5-XBGI19OWrE6RSltGekvjf array-0.5.4.0
    base-4.16.4.0 colour-2.3.6-DMgYzCMG1eF1QrJvWxFUqJ mtl-2.2.2
    path-0.9.5-7tuwZi4KZVX9taYoAHFT9p
    rio-0.1.22.0-KKgQcmK15TUDXW7QWzkjAe text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-rio-prettyprint/html/rio-prettyprint.haddock

haddock-html:         /usr/share/doc/haskell-rio-prettyprint/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rio-prettyprint-0.1.6.0-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-rio-prettyprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rio-prettyprint
version:              0.1.6.0
visibility:           public
id:                   rio-prettyprint-0.1.6.0-7RUluse3Y3H9fpIsBMlYfv
key:                  rio-prettyprint-0.1.6.0-7RUluse3Y3H9fpIsBMlYfv
license:              BSD-3-Clause
copyright:            2018-2019 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/rio-prettyprint#readme
synopsis:             Pretty-printing for RIO
description:          Combine RIO'\''s log capabilities with pretty printing
category:             Development
abi:                  8e3aa1d1dc496c5f65761e5535abb8cd
exposed:              True
exposed-modules:
    RIO.PrettyPrint RIO.PrettyPrint.DefaultStyles
    RIO.PrettyPrint.PrettyException RIO.PrettyPrint.Simple
    RIO.PrettyPrint.StylesUpdate RIO.PrettyPrint.Types
    Text.PrettyPrint.Leijen.Extended

hidden-modules:       Paths_rio_prettyprint
import-dirs:          /usr/lib/ghc-9.2.8/site-local/rio-prettyprint-0.1.6.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/rio-prettyprint-0.1.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rio-prettyprint
hs-libraries:         HSrio-prettyprint-0.1.6.0-7RUluse3Y3H9fpIsBMlYfv
depends:
    Cabal-3.6.3.0 aeson-2.1.2.1-IkP1OjeNuTxglWxWeIvI9
    annotated-wl-pprint-0.7.0-JJ8k3Us8XMDCld6qYY6FFz
    ansi-terminal-0.11.5-GmxlGl1eC6rGTjWL8Yprft array-0.5.4.0
    base-4.16.4.0 colour-2.3.6-KDhjTRIL7rnBhoKfQ21QbO mtl-2.2.2
    path-0.9.5-CRaajd6YBgrKQxsmIji1p3
    rio-0.1.22.0-Fk5dgBqBaN4Fz2FI74bXfa text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-rio-prettyprint/html/rio-prettyprint.haddock

haddock-html:         /usr/share/doc/haskell-rio-prettyprint/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
